@@ -180,9 +180,6 @@ def create_label(
         hover_background_color = "#1e1e1e",
         hover_border_width = 0,
         hover_border_color = "#777777",
-        pressed_background_color = "#1e1e1e",
-        pressed_border_width = 0,
-        pressed_border_color = "#0078d7",
         disabled_font_color = "#888888",
         disabled_background_color = "#2d2d2d",
         disabled_border_width = 0,
@@ -211,10 +208,6 @@ def create_label(
             background-color: {hover_background_color};
             border: {hover_border_width}px solid {hover_border_color};
         }}
-        QLabel:pressed{{
-            background-color: {pressed_background_color};
-            border: {pressed_border_width}px solid {pressed_border_color};
-        }}
         QLabel:disabled{{
             color: {disabled_font_color};
             background-color: {disabled_background_color};
@@ -254,7 +247,7 @@ def create_button(
     button.setMaximumWidth(360)
     main_layout = QVBoxLayout()
     button.setLayout(main_layout)
-    main_layout.setContentsMargins(0, 0, 0, 0)
+    main_layout.setContentsMargins(border_width, border_width, border_width, border_width)
     label = create_label(
         text = text,
         font_size = font_size,
@@ -266,19 +259,9 @@ def create_button(
         padding_top = padding_top,
         padding_right = padding_right,
         padding_bottom = padding_bottom,
-        border_width = border_width,
-        border_color = border_color,
-        border_radius = border_radius,
         hover_background_color = hover_background_color,
-        hover_border_width = hover_border_width,
-        hover_border_color = hover_border_color,
-        pressed_background_color = pressed_background_color,
-        pressed_border_width = pressed_border_width,
-        pressed_border_color = pressed_border_color,
-        disabled_font_color = disabled_font_color,
         disabled_background_color = disabled_background_color,
-        disabled_border_width = disabled_border_width,
-        disabled_border_color = disabled_border_color
+        disabled_border_width = disabled_border_width
     )
     label.setAlignment(Qt.AlignmentFlag.AlignCenter)
     label.setWordWrap(True)
@@ -316,6 +299,7 @@ def create_button(
         }}
     """
     button.setStyleSheet(style_sheet)
+    button.setFixedHeight(main_layout.sizeHint().height() + 2 * border_width)
     return button
 
 def create_text_box(
